"GSload.exp" <-
function(filename="GS_R_in.txt", EOF="///", chunk=1) {

#Last update: 17-Jan-2007
#We are first finding out which chunk we need to read for the experiment
#We are padding the the file and the list of EOF characters with the first and last line position, to make it easier to do all the calculations
l<-c(readLines(filename),"")
eofs <- c(0,grep(EOF,l),length(l))
if( chunk < length(eofs) ) {
   skipping <- eofs[chunk]
   ending <- eofs[chunk+1]-eofs[chunk]-1
} else {
   return(NULL)
}

#We now know where our interpretation is supposed to be

#Read the experiment name; It's the first line in the file
expName<-as.vector(read.table(filename,skip=skipping, nrows=1,sep="\t")[1,1])

#Read the header
#Unfortunately we have to read the file two times, since it will get confused by the format
# and make all the datapoints factors
#We are skipping the first line, since we know that contains the experiment name
# AND we are reading in a maximum of 200 lines since it is very unlikely there will be more than 200 parameters
expr <- read.table(filename,sep="\t",quote="",skip=skipping+1,header=FALSE,row.names=NULL,blank.lines.skip=FALSE,nrows=min(200,ending-1), comment.char="",as.is=TRUE)

#Figure out how many columns there are for each sample
# There can be either one or two columns.
# If there are two columns, the third column is called "control" so we simply determine if the second column is control
# If not, it is a one column format
numCol <- if(dim(expr)[2]>2 && (expr[1,3]=="control")) 2 else 1

#Now find the start of the real data.
#The header represents the names of the experimental parameters
# The Header consists of the names of the parameters with the parameters all having parentheses in their names
# So we are simply looking for rownames that do NOT have the ( character, by finding all those rows with a ( and taking the last number for that list
#Agilent arrays may have some probenames that have a ( as their first character.
# To avoid mistaking those genes for parameters, we are only looking for the ( character if it is preceded by at least one other character
# This is a bit of hack, but will work in most cases
nl <- grep("[^(]+[^(]+[(]",expr[,1])
n <- if(length(nl)==0) 0 else nl[length(nl)]

#Get number of conditions
numConditions <- (dim(expr)[2]-1)/numCol

#Make a table with the experimental parameters
#We only need every numCol'th column, since the second column is simply saying 'control' for experiments
#We will get a table with the row names representing the experimental parameters
# and the columns contain the values for each of the conditions.

if(n > 0) {
   expparam <- data.frame(expr[1:n,2+numCol*0:(numConditions-1)],row.names=sub(' [(].*','',expr[1:n,1]))
} else {
   expparam <- data.frame(t(1:numConditions),row.names="Parameter")
}


#We will read the file again, since I cannot figure out how to NOT get factors for the numbers
expr <- read.table(filename,sep="\t",quote="",skip=skipping+n+1,header=FALSE,row.names=NULL,blank.lines.skip=FALSE,comment.char="",as.is=TRUE, nrows=ending-n-1)

#Get the normalized values for the experiment and if we have them, the control values
a.nor <- expr[,2+numCol*0:(numConditions-1)]
if(numCol == 2) a.ctr <- expr[,3+numCol*0:(numConditions-1)] else a.ctr <- matrix(nc=0, nr=0)

#Set the column names to simple numbers
if (numConditions > 1) colnames(a.nor) <- 1:numConditions
if(numCol == 2) colnames(a.ctr) <- 1:numConditions

#Get number of genes
ngenes <- dim(expr)[1]

#Get the names of the genes
genenames <- expr[,1]

#return the GSint object
GSint(a.nor=a.nor, a.ctr=a.ctr, expparam=expparam, expName=expName, numConditions=numConditions, ngenes=ngenes, genenames=genenames)

} ####End of function definition GSload.exp()