\name{GSsave.exp}
\alias{GSsave.exp}
\title{Save a GeneSpring Interpretation to file}
\description{
The normalized values of the GeneSpring Interpretation object will be written to file.
If the Interpretation object contains Control values, they will also be used.
The experimental parameters and the experiment name will also be included.
}
\usage{
GSsave.exp(interpretation, filename = "GS_R_out.txt", EOF = "///", append = TRUE)
}
\arguments{
  \item{interpretation}{The GeneSpring Experiment Interpretation object of class \code{GSint}.}
  \item{filename}{Name of the file. Can also be a connection object.}
  \item{EOF}{String containing the delimiter used to separate the chunks in the file to be read.}
  \item{append}{Boolean indicating if the experiment should be appended to the output, allowing for multiple objects to be send back to GeneSpring.}
}
\details{
A GeneSpring Experiment consists of the Normalized expression values for each sample
and optionally the Control values for that normalized value. Each sample or hybridization
has its own column (set) of expression values, where the expression values for an Experiment
INTERPRETATION represent the mean value of the replicate values for that condition.

GeneSpring will be able to read multiple objects, and it requires the R program to store all
objects in one file, one object per "chunk", separated by a delimiter on its own line. The
order in which the objects are defined (in the "Output" section of the External Program
Interface definition) determines in which chunk the interpretation should be read by GeneSpring.

For more information see the manual entry for \code{\link{GSload.exp}}.
}
\value{
This function does not return a usable value upon return.
}
\references{
For more information on using GeneSpring with R see
\url{http://www.chem.agilent.com/scripts/generic.asp?lpage=34733}
}
\author{
   Thon de Boer, Agilent Technologies, Santa Clara, CA, USA \email{thon\_deboer@agilent.com}
}
\note{
This and any other functions in the GeneSpring package are only useful
when using Agilent Technologies Gene Expression software GeneSpring.
}
\seealso{
\code{\link{GSload.exp}},
\code{\link{GSload.int}}
}
\examples{
#Use the example data etc. from ExpressionSet
library(Biobase)
data(geneData)
data(geneCov)
covdesc<- list("Covariate 1", "Covariate 2", "Covariate 3")
names(covdesc) <- names(geneCov)
pdata <- new("AnnotatedDataFrame")
pData(pdata) <- geneCov
varLabels(pdata) <- covdesc
eset <- new("ExpressionSet", exprs=geneData, phenoData=pdata)

#Convert the objects into GeneSpring objects
gs.int <- BC2GSint(eset)

#Save the Experiment in GeneSpring format
GSsave.exp(gs.int, filename = "GS_R_out.txt")
}
\keyword{IO}
